@@ -3,7 +3,7 @@ from asyncpg import Connection
 
 from .constraint import (Assignments, BinaryConstraint, Constraints,
                          DictConstraint, GroupConstraint, Literal,
-                         TextConstraint)
+                         MappedPlaceholder, TextConstraint)
 from .db import DB, DBBase
 from .exceptions import RollbackTransactionException
 from .types import (ConnectionArgs, LimitOffset, Record, Records,
