@@ -1,22 +1,21 @@
 """Contains the DB wrapper class."""
 from contextlib import asynccontextmanager
 from time import time
-from typing import (Any, AsyncIterator, Awaitable, Iterable, List, Optional,
-                    cast)
+from typing import Any, AsyncIterator, Iterable, List, Optional, cast
 
 from asyncpg import Connection, connect
 
-import apgw.builder as builder
-from apgw.constraint import Assignments, Constraints
-from apgw.types import (ConnectionArgs, InsertAssignments, LimitOffset, Params,
-                        Record, Records, RecordsAndCount)
+from . import builder
+from .constraint import Assignments, Constraints
+from .types import (ConnectionArgs, InsertAssignments, LimitOffset, Params,
+                    Record, Records, RecordsAndCount)
 
 
 class DBBase:
     """A simple wrapper around asyncpg to alleviate some boilerplate."""
 
     def __init__(self) -> None:
-        """Initializes the DB instance. """
+        """Initializes the DB instance."""
         self._conn: Optional[Connection] = None
         self._is_in_transaction: bool = False
 
@@ -62,13 +61,15 @@ class DBBase:
     async def get_connection_args(self) -> ConnectionArgs:
         raise NotImplementedError()
 
-    async def connect(self, connection_args: ConnectionArgs) -> "Connection":
+    @staticmethod
+    async def connect(connection_args: ConnectionArgs) -> "Connection":
         """Override this method to customize how the connection is open. For instance you could
         use a connection pool's acquire method.
         """
         return await connect(**connection_args)
 
-    async def disconnect(self, connection: Connection):
+    @staticmethod
+    async def disconnect(connection: Connection):
         """Override this method to customize how the connection is closed. For instance you could
         use a connection pool's release method.
         """
@@ -111,7 +112,7 @@ class DBBase:
         """Asynchronous context manager exit point."""
         await self.close()
 
-    async def execute(self, sql: Optional[str], params: Optional[Params] = None):
+    async def execute(self, sql: Optional[str], params: Optional[Params] = None) -> str:
         """This method passes through to self.conn.execute.
 
         :param sql: the parameterized sql to execute
@@ -126,9 +127,8 @@ class DBBase:
 
         try:
             if params:
-                await self.conn.execute(sql, *params)
-            else:
-                await self.conn.execute(sql)
+                return await self.conn.execute(sql, *params)
+            return await self.conn.execute(sql)
         except Exception as ex:
             error = ex
             raise
@@ -437,6 +437,10 @@ class DB(DBBase):
         return self._conn_args
 
     async def log(
-        self, sql: str, params: Optional[Params], duration: float, error: bool
+        self,
+        sql: str,
+        params: Optional[Params],
+        duration: float,
+        error: Optional[Exception],
     ) -> None:
         pass
