@@ -1,8 +1,7 @@
 """Shared types."""
 from typing import Any, List, Mapping, Optional, Tuple, Union
 
-ConnectArgs = Mapping[str, Any]
-ConnectionArgs = Union[ConnectArgs, str]
+ConnectionArgs = Mapping[str, Any]
 
 InsertAssignments = Union[
     Mapping[str, Any],
@@ -15,4 +14,5 @@ Record = Mapping[str, Any]
 Records = List[Record]
 RecordsAndCount = Tuple[Records, int]
 
-SQL = Tuple[Optional[str], List[Any]]
+Params = List[Any]
+SQL = Tuple[Optional[str], Params]
